==> qtjambi-multimedia-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiMultimedia/QImageCapture_shell.h <==
#ifndef QIMAGECAPTURE_SHELL_H
#define QIMAGECAPTURE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtMultimedia/qimagecapture.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qimage.h>
#include <QtMultimedia/qmediacapturesession.h>
#include <QtMultimedia/qmediametadata.h>
#include <QtMultimedia/qvideoframe.h>
#include <QtJambi/RegistryAPI>


class QImageCapture_shell : public QImageCapture, public QtJambiShellInterface
{
public:
    QImageCapture_shell(QObject* parent0 = nullptr);
    ~QImageCapture_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QImageCapture_access : public QImageCapture
{
};

#endif // QIMAGECAPTURE_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiMultimedia/QImageCapture_shell.h <==
#ifndef QIMAGECAPTURE_SHELL_H
#define QIMAGECAPTURE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qimagecapture.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qimage.h>
#include <QtMultimedia/qmediacapturesession.h>
#include <QtMultimedia/qmediametadata.h>
#include <QtMultimedia/qvideoframe.h>
#include <QtJambi/RegistryAPI>


class QImageCapture_shell : public QImageCapture, public QtJambiShellInterface
{
public:
    QImageCapture_shell(QObject* parent0 = nullptr);
    ~QImageCapture_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QImageCapture_mshell;
    friend class QImageCapture_oshell;
};


class QImageCapture_mshell : public QImageCapture_shell
{
public:
    using QImageCapture_shell::QImageCapture_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QImageCapture_oshell : public QImageCapture_mshell
{
public:
    using QImageCapture_mshell::QImageCapture_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QImageCapture_access : public QImageCapture
{
};

#endif // QIMAGECAPTURE_SHELL_H
